@@ -90,14 +90,27 @@ class fMMS_controller():
 	""" from http://snippets.dzone.com/posts/show/655 """
 	def image2pixbuf(self, im):
 		file1 = StringIO.StringIO()
-		im.save(file1, "ppm")
-		contents = file1.getvalue()
-		file1.close()
-		loader = gtk.gdk.PixbufLoader("pnm")
-		loader.write(contents, len(contents))
-		pixbuf = loader.get_pixbuf()
-		loader.close()
-		return pixbuf
+		try:
+			im.save(file1, "ppm")
+			contents = file1.getvalue()
+			file1.close()
+			loader = gtk.gdk.PixbufLoader("pnm")
+			loader.write(contents, len(contents))
+			pixbuf = loader.get_pixbuf()
+			loader.close()
+			return pixbuf
+		except IOError, e:
+			log.exception("Failed to convert")
+			im.save(file1, "gif")
+			contents = file1.getvalue()
+			file1.close()
+			loader = gtk.gdk.PixbufLoader()
+			loader.write(contents, len(contents))
+			pixbuf = loader.get_pixbuf()
+			loader.close()
+			return pixbuf
+			
+		
 	
 	
 	def convert_timeformat(self, intime, format, hideToday=False):
@@ -284,7 +297,8 @@ class fMMS_controller():
 		return self.store.get_mms_headers(transactionid)
 	
 	def delete_mms_message(self, fname):
-		fullpath = self._mmsdir + fname
+		#fullpath = self._mmsdir + fname
+		fullpath = self.store.get_filepath_for_mms_transid(fname)
 		log.info("fullpath: %s", fullpath)
 		if os.path.isdir(fullpath):
 			log.info("starting deletion of %s", fullpath)
@@ -308,7 +322,8 @@ class fMMS_controller():
 		self.store.delete_mms_message(fname)
 		
 	def delete_push_message(self, fname):
-		fullpath = self._pushdir + fname
+		#fullpath = self._pushdir + fname
+		fullpath = self.store.get_filepath_for_push_transid(fname)
 		log.info("fullpath: %s", fullpath)
 		if os.path.isfile(fullpath):
 			log.info("removing: %s", fullpath)
